#
# spec file for package typescript
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           typescript
Version:        5.3.3
Release:        1.1
Summary:        A language for application scale JavaScript development
License:        Apache-2.0
Group:          Development/Libraries/Other
URL:            http://typescriptlang.org/
Source0:        https://github.com/microsoft/TypeScript/releases/download/v%{version}/%{name}-%{version}.tgz
BuildRequires:  fdupes
BuildRequires:  nodejs-packaging
BuildArch:      noarch
%{?nodejs_requires}

%description
TypeScript is a language for application-scale JavaScript. TypeScript adds
optional types, classes, and modules to JavaScript. TypeScript supports tools
for large-scale JavaScript applications for any browser, for any host, on any
OS. TypeScript compiles to readable, standards-based JavaScript.

%prep
%setup -q -n package

sed -i 's/\r$//' ThirdPartyNoticeText.txt
sed -i 's/\r$//' README.md
sed -i 's/\r$//' LICENSE.txt

%build

%install
%nodejs_install

# Fix shebang lines
for file in %{buildroot}%{_bindir}/ts* ; do
    sed -i -e "s|#!%{_bindir}/env node|#!%{_bindir}/node|" $(readlink -f $file)
done

%fdupes %{buildroot}

%files
%license LICENSE.txt ThirdPartyNoticeText.txt
%doc README.md
%dir %{nodejs_sitelib}
%{nodejs_sitelib}/%{name}
%{_bindir}/tsc
%{_bindir}/tsserver

%changelog
* Sun Dec 10 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 5.3.3:
  * Make JSDoc Parsing Configurable using the transpileModule method
  * Fixed an issue in boolean comparison narrowing when the reference is an optional chain
  * Type narrowing regression with property comparison to boolean false
  * Deprecated types (AssertEntry, AssertClause) redefined as type aliases, rather than interfaces
  * Type error in typescript.d.ts with exactOptionalPropertyTypes = true
* Fri Nov 24 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 5.3.2:
  * Import Attributes
  * Stable Support resolution-mode in Import Types
  * resolution-mode Supported in All Module Modes
  * switch (true) Narrowing
  * Narrowing On Comparisons to Booleans
  * instanceof Narrowing Through Symbol.hasInstance
  * Checks for super Property Accesses on Instance Fields
  * Interactive Inlay Hints for Types
  * Settings to Prefer type Auto-Imports
  * Optimizations by Skipping JSDoc Parsing
  * Optimizations by Comparing Non-Normalized Intersections
  * Consolidation Between tsserverlibrary.js and typescript.js
  * for details see https://devblogs.microsoft.com/typescript/announcing-typescript-5-3/
  * Breaking Changes and Correctness Improvements:
  - lib.d.ts Changes
    Types generated for the DOM may have an impact on your codebase.
    For more information, see the DOM updates for TypeScript 5.3.
    https://github.com/microsoft/TypeScript/pull/55798
* Sat Aug 26 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 5.2.2:
  * 'using' Declarations and Explicit Resource Management
  * Decorator Metadata
  * Named and Anonymous Tuple Elements
  * Easier Method Usage for Unions of Arrays
  * Copying Array Methods
  * symbols as WeakMap and WeakSet Keys
  * Type-Only Import Paths with TypeScript Implementation File Extensions
  * Comma Completions for Object Members
  * Inline Variable Refactoring
  * Optimized Checks for Ongoing Type Compatibility
  * Breaking changes and Correctness fixes: see
    https://devblogs.microsoft.com/typescript/announcing-typescript-5-2/#breaking-changes-and-correctness-fixes
* Fri Aug 11 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 5.1.6:
  * See https://www.typescriptlang.org/docs/handbook/release-notes/typescript-5-1.html
    and https://www.typescriptlang.org/docs/handbook/release-notes/typescript-5-0.html
  * Breaking change:
  TypeScript 5.1 now ships JavaScript functionality that was introduced in ECMAScript 2020.
  As a result, at minimum TypeScript must be run in a reasonably modern runtime.
  For most users, this means TypeScript now only runs on Node.js 14.17 and later.
* Sat Feb 25 2023 Lukas Müller <expeehaa@outlook.com>
- Update to version 4.9.5.
  * See https://www.typescriptlang.org/docs/handbook/release-notes/typescript-4-9.html
    and equivalent pages for the changelogs of this version and those in between.
* Mon Apr 12 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 4.2.4
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Thu Mar 11 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 4.2.3
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Sun Feb 28 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 4.2.2
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Sun Feb  7 2021 Mustafa Çalışkan <musfay@protonmail.com>
- Update to version 4.1.3
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Wed Sep 23 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 4.0.3
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Mon Aug  3 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.9.7
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Mon Jun  8 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.9.5
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Wed May 20 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.9.3
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Wed May 13 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.9.2
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Fri May  1 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 3.8.3
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Fri Jan 17 2020 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.7.5
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Tue Dec 24 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.7.4
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Wed Dec  4 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.7.3
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Sun Dec  1 2019 Ismail Dönmez <idonmez@suse.com>
- Update to version 3.7.2
  * See https://www.typescriptlang.org/docs/handbook/release-notes/overview.html
    for a complete changelog.
* Sun Nov 25 2018 Matej Cepl <mcepl@suse.com>
- Upgrade to 3.1.6. The list of changes is too long, you can find
  infromation about changes on the TypeScript wiki, e.g., in
  https://github.com/Microsoft/TypeScript/wiki/What%%27s-new-in-TypeScript
* Thu Mar 16 2017 carlos@techbyte.ca
- Updating to 2.2.1
* Thu Feb  9 2017 carlos@techbyte.ca
- Downgrading to 2.1.6
* Thu Feb  9 2017 carlos@techbyte.ca
- Bumping to 2.2.0
* Wed Feb  8 2017 carlos@techbyte.ca
- Renaming package
* Wed Feb  8 2017 carlos@techbyte.ca
- Initial release.
